/*
Copyright 2010 GHI Electronics LLC
Licensed under the Apache License, Version 2.0 (the "License"); you may not use this file except in compliance with the License. You may obtain a copy of the License at
http://www.apache.org/licenses/LICENSE-2.0
Unless required by applicable law or agreed to in writing, software distributed under the License is distributed on an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the License for the specific language governing permissions and limitations under the License. 
*/

using System;
using GHIElectronics.NETMF.Hardware;
using GHIElectronics.NETMF.FEZ;
using Microsoft.SPOT;

namespace GHIElectronics.NETMF.FEZ
{
    public static partial class FEZ_Components
    {
        public class Thermometer : IDisposable
        {
            AnalogIn adc;

            public void Dispose()
            {
                adc.Dispose();
            }

            public Thermometer(FEZ_Pin.AnalogIn pin)
            {
                adc = new AnalogIn((AnalogIn.Pin)pin);
                adc.SetLinearScale(-44, 112);
            }

            public float GetTemperatureCelsius()
            {
                return adc.Read() / 2f;
            }

            public float GetTemperatureFahrenheit()
            {
                float c = GetTemperatureCelsius();

                return c * 9 / 5 + 32;
            }
        }
    }
}